==> nextcloud-19.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/fi.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Kommentit",
    "You commented" : "Kommentoit",
    "%1$s commented" : "%1$s kommentoi",
    "{author} commented" : "{author} kommentoi",
    "You commented on %1$s" : "Kommentoit %1$s",
    "You commented on {file}" : "Kommentoit tiedostoa {file}",
    "%1$s commented on %2$s" : "%1$s kommentoi kohdetta %2$s",
    "{author} commented on {file}" : "{author} kommentoi tiedostoa {file}",
    "<strong>Comments</strong> for files" : "Tiedostojen <strong>kommentit</strong>",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Sinut mainittiin tiedoston “{file}” kommentissa käyttäjän toimesta, joka on sittemmin poistettu",
    "{user} mentioned you in a comment on “{file}”" : "{user} mainitsi sinut tiedoston \"{file}\" kommentissa",
    "Edit comment" : "Muokkaa kommenttia",
    "Delete comment" : "Poista kommentti",
    "New comment …" : "Uusi kommentti…",
    "Post" : "Lähetä",
    "Cancel" : "Peruuta",
    "[Deleted user]" : "[Poistettu käyttäjä]",
    "No comments yet, start the conversation!" : "Ei kommentteja vielä. Aloita keskustelu!",
    "More comments …" : "Lisää kommentteja…",
    "Save" : "Tallenna",
    "Allowed characters {count} of {max}" : "Sallittujen merkkien määrä {count}/{max}",
    "Error occurred while retrieving comment with ID {id}" : "Virhe haettaessa kommenttia tunnisteella {id}",
    "Error occurred while updating comment with id {id}" : "Virhe päivittäessä kommenttia tunnisteella {id}",
    "Error occurred while posting comment" : "Virhe kommenttia lähettäessä",
    "_%n unread comment_::_%n unread comments_" : ["%n lukematon kommentti","%n lukematonta kommenttia"],
    "_1 new comment_::_{unread} new comments_" : ["1 uusi kommentti","{unread} uutta kommenttia"],
    "Comment" : "Kommentti"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-22.2.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/fi.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Kommentit",
    "You commented" : "Kommentoit",
    "%1$s commented" : "%1$s kommentoi",
    "{author} commented" : "{author} kommentoi",
    "You commented on %1$s" : "Kommentoit %1$s",
    "You commented on {file}" : "Kommentoit tiedostoa {file}",
    "%1$s commented on %2$s" : "%1$s kommentoi kohdetta %2$s",
    "{author} commented on {file}" : "{author} kommentoi tiedostoa {file}",
    "<strong>Comments</strong> for files" : "Tiedostojen <strong>kommentit</strong>",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Sinut mainittiin tiedoston “{file}” kommentissa käyttäjän toimesta, joka on sittemmin poistettu",
    "{user} mentioned you in a comment on “{file}”" : "{user} mainitsi sinut tiedoston \"{file}\" kommentissa",
    "Edit comment" : "Muokkaa kommenttia",
    "Delete comment" : "Poista kommentti",
    "Cancel edit" : "Peruuta muokkaus",
    "Post comment" : "Lähetä viesti",
    "No comments yet, start the conversation!" : "Ei kommentteja vielä. Aloita keskustelu!",
    "No more messages" : "Ei enempää viestejä",
    "Retry" : "Yritä uudelleen",
    "Unable to load the comments list" : "Kommenttilistaa ei voitu ladata",
    "_%n unread comment_::_%n unread comments_" : ["%n lukematon kommentti","%n lukematonta kommenttia"],
    "_1 new comment_::_{unread} new comments_" : ["1 uusi kommentti","{unread} uutta kommenttia"],
    "Comment" : "Kommentti",
    "An error occurred while trying to edit the comment" : "Kommenttia muokatessa tapahtui virhe",
    "Comment deleted" : "Kommentti poistettu",
    "An error occurred while trying to delete the comment" : "Kommenttia poistaessa tapahtui virhe",
    "An error occurred while trying to create the comment" : "Kommenttia luodessa tapahtui virhe",
    "New comment …" : "Uusi kommentti…",
    "Post" : "Lähetä",
    "Cancel" : "Peruuta",
    "[Deleted user]" : "[Poistettu käyttäjä]",
    "More comments …" : "Lisää kommentteja…",
    "Save" : "Tallenna",
    "Allowed characters {count} of {max}" : "Sallittujen merkkien määrä {count}/{max}",
    "Error occurred while retrieving comment with ID {id}" : "Virhe haettaessa kommenttia tunnisteella {id}",
    "Error occurred while updating comment with id {id}" : "Virhe päivittäessä kommenttia tunnisteella {id}",
    "Error occurred while posting comment" : "Virhe kommenttia lähettäessä"
},
"nplurals=2; plural=(n != 1);");
